"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const config_1 = require("../../lib/config");
class RemoveEndpointCommand extends core_1.Command {
    async run() {
        const config = config_1.ShellConfig.read({});
        await this.execute(config);
    }
    async execute(config) {
        const { args } = await this.parse();
        const name = args.name;
        if (config.rootConfig.endpoints[name] === undefined) {
            this.error(`No such endpoint ${name}`);
        }
        // Clear the default if `name` is the default.
        if (config.rootConfig.defaultEndpoint === name) {
            config.rootConfig.defaultEndpoint = undefined;
        }
        delete config.rootConfig.endpoints[name];
        config.saveRootConfig();
        this.log(`Removed endpoint ${name}.`);
    }
}
RemoveEndpointCommand.description = "Remove an endpoint from ~/.fauna-shell.";
RemoveEndpointCommand.examples = ["$ fauna endpoint remove my_endpoint"];
RemoveEndpointCommand.flags = {};
RemoveEndpointCommand.args = {
    name: core_1.Args.string({
        required: true,
        description: "Endpoint name",
    }),
};
RemoveEndpointCommand.aliases = ["delete-endpoint"];
RemoveEndpointCommand.deprecateAliases = true;
exports.default = RemoveEndpointCommand;
