"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = require("../../lib/config/index");
const core_1 = require("@oclif/core");
const search_select_1 = require("../../lib/search-select");
class DefaultEndpointCommand extends core_1.Command {
    async run() {
        const config = index_1.ShellConfig.read({});
        await this.execute(config);
    }
    async execute(config) {
        var _a;
        const { args } = await this.parse();
        if (Object.keys(config.rootConfig.endpoints).length === 0) {
            this.error("No endpoints defined. Create one with `fauna cloud-login`");
        }
        const name = (_a = args.name) !== null && _a !== void 0 ? _a : (await (0, search_select_1.searchSelect)({
            message: "Select a new default endpoint",
            choices: Object.keys(config.rootConfig.endpoints).map((endpoint) => ({
                value: endpoint,
            })),
        }));
        if (config.rootConfig.endpoints[name] === undefined) {
            this.error(`No such endpoint ${name}`);
        }
        config.rootConfig.defaultEndpoint = name;
        config.saveRootConfig();
        this.log(`Updated default endpoint to ${name}.`);
    }
}
DefaultEndpointCommand.description = "Set an endpoint as the default one.";
DefaultEndpointCommand.examples = [
    "$ fauna endpoint select",
    "$ fauna endpoint select endpoint",
];
DefaultEndpointCommand.args = {
    name: core_1.Args.string({
        required: false,
        description: "New default endpoint",
    }),
};
DefaultEndpointCommand.aliases = ["default-endpoint"];
DefaultEndpointCommand.deprecateAliases = true;
exports.default = DefaultEndpointCommand;
