"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const config_1 = require("../../lib/config");
const environment_factory_1 = require("../../lib/environment-factory");
class AddEnvironmentCommand extends core_1.Command {
    async run() {
        const config = config_1.ShellConfig.read({}, this);
        await this.execute(config);
    }
    async execute(config) {
        const { flags } = await this.parse();
        if (config.projectConfig === undefined) {
            this.error("No `.fauna-project` found. Create one with `fauna project init`.");
        }
        const environmentFactory = new environment_factory_1.EnvironmentFactory(this, config);
        await environmentFactory.addEnvironment({
            endpoint: flags.endpoint,
            database: flags.database,
            name: flags.name,
            default: flags["set-default"],
            nonInteractive: flags["non-interactive"],
        });
    }
}
AddEnvironmentCommand.flags = {
    name: core_1.Flags.string({
        description: "New environment name",
    }),
    endpoint: core_1.Flags.string({
        description: "Endpoint to use in this environment",
    }),
    database: core_1.Flags.string({
        description: "Database path to use in this environment",
    }),
    "non-interactive": core_1.Flags.boolean({
        description: "Disable interaction",
        dependsOn: ["name", "endpoint", "database"],
    }),
    "set-default": core_1.Flags.boolean({
        description: "Set this environment as the default",
    }),
};
AddEnvironmentCommand.description = `Add a new environment to \`.fauna-project\`.

NOTE: \`fauna project\` and \`fauna environment\` are still in beta. Behavior is subject to change.`;
AddEnvironmentCommand.examples = [
    "$ fauna environment add",
    "$ fauna environment add --name my-app --endpoint dev --database my-database",
    "$ fauna environment add --name my-app --endpoint dev --database my-database --set-default",
];
exports.default = AddEnvironmentCommand;
