"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const config_1 = require("../../lib/config");
class SelectEnvironmentCommand extends core_1.Command {
    async run() {
        const config = config_1.ShellConfig.read({}, this);
        await this.execute(config);
    }
    async execute(config) {
        const { args } = await this.parse();
        if (config.projectConfig === undefined) {
            this.error("No project config found");
        }
        if (!Object.keys(config.projectConfig.environments).includes(args.environment)) {
            this.error(`Environment ${args.environment} not found in project config. Run \`fauna environment list\` to see available environments`);
        }
        config.projectConfig.defaultEnvironment = args.environment;
        config.saveProjectConfig();
        console.log(`Selected environment ${args.environment}`);
    }
}
SelectEnvironmentCommand.args = {
    environment: core_1.Args.string({
        description: "The new default environment to use",
        required: true,
    }),
};
SelectEnvironmentCommand.description = `Update the default environment in \`.fauna-project\`.

NOTE: \`fauna project\` and \`fauna environment\` are still in beta. Behavior is subject to change.`;
SelectEnvironmentCommand.examples = ["$ fauna environment select my-environment"];
exports.default = SelectEnvironmentCommand;
