export = EvalCommand;
declare class EvalCommand extends FaunaCommand {
    static description: string;
    writeFormattedOutputV10(file: any, res: any, format: any): Promise<any>;
    /**
     * Perform a v4 or v10 query, depending on the FQL version
     *
     * @param {Object} client - An instance of the client used to execute the query.
     * @param {string} fqlQuery - The FQL v4 query to be executed.
     * @param {string} outputFile - Target filename
     * @param {Object} flags - Options for the query execution.
     * @param {("4" | "10")} flags.version - FQL version number
     * @param {("json" | "json-tagged" | "shell")} flags.format - Result format
     * @param {boolean} [flags.typecheck] - (Optional) Flag to enable typechecking
     */
    performQuery(client: Object, fqlQuery: string, outputFile: string, flags: {
        version: ("4" | "10");
        format: ("json" | "json-tagged" | "shell");
        typecheck?: boolean | undefined;
    }): Promise<any>;
    performV10Query(client: any, fqlQuery: any, outputFile: any, flags: any): Promise<any>;
    performV4Query(client: any, fqlQuery: any, outputFile: any, flags: any): Promise<any>;
    getArgs(): {
        query: any;
        dbname?: undefined;
    } | {
        dbname: any;
        query: any;
    };
}
declare namespace EvalCommand {
    let examples: string[];
    let flags: {
        file: import("@oclif/core/lib/interfaces/parser.js").OptionFlag<string | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
        stdin: import("@oclif/core/lib/interfaces/parser.js").BooleanFlag<boolean>;
        output: (import("@oclif/core/lib/interfaces/parser.js").FlagProps & {
            type: "option";
            helpValue?: string | undefined;
            options?: string[] | undefined;
            multiple?: boolean | undefined;
        } & {
            parse: import("@oclif/core/lib/interfaces/parser.js").FlagParser<string[], string, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            defaultHelp?: import("@oclif/core/lib/interfaces/parser.js").FlagDefaultHelp<string[], import("@oclif/core/lib/interfaces/parser.js").CustomOptions> | undefined;
            input: string[];
        } & {
            default?: import("@oclif/core/lib/interfaces/parser.js").FlagDefault<string[] | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            multiple: false;
        } & {
            parse: import("@oclif/core/lib/interfaces/parser.js").FlagParser<string[] | undefined, string, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            defaultHelp?: import("@oclif/core/lib/interfaces/parser.js").FlagDefaultHelp<string[] | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            input: string[];
        } & {
            default?: import("@oclif/core/lib/interfaces/parser.js").FlagDefault<string[] | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            multiple: false;
        } & {
            parse: import("@oclif/core/lib/interfaces/parser.js").FlagParser<string, string, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            defaultHelp?: import("@oclif/core/lib/interfaces/parser.js").FlagDefaultHelp<string, import("@oclif/core/lib/interfaces/parser.js").CustomOptions> | undefined;
            input: string[];
        } & {
            default?: import("@oclif/core/lib/interfaces/parser.js").FlagDefault<string | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            multiple: false;
        } & {
            parse: import("@oclif/core/lib/interfaces/parser.js").FlagParser<string | undefined, string, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            defaultHelp?: import("@oclif/core/lib/interfaces/parser.js").FlagDefaultHelp<string | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            input: string[];
        } & {
            default?: import("@oclif/core/lib/interfaces/parser.js").FlagDefault<string | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            multiple: false;
        }) | (import("@oclif/core/lib/interfaces/parser.js").FlagProps & {
            type: "option";
            helpValue?: string | undefined;
            options?: string[] | undefined;
            multiple?: boolean | undefined;
        } & {
            parse: import("@oclif/core/lib/interfaces/parser.js").FlagParser<string[], string, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            defaultHelp?: import("@oclif/core/lib/interfaces/parser.js").FlagDefaultHelp<string[], import("@oclif/core/lib/interfaces/parser.js").CustomOptions> | undefined;
            input: string[];
        } & {
            default?: import("@oclif/core/lib/interfaces/parser.js").FlagDefault<string[][] | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            multiple: true;
        } & {
            parse: import("@oclif/core/lib/interfaces/parser.js").FlagParser<string[] | undefined, string, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            defaultHelp?: import("@oclif/core/lib/interfaces/parser.js").FlagDefaultHelp<string[] | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            input: string[];
        } & {
            default?: import("@oclif/core/lib/interfaces/parser.js").FlagDefault<(string[] | undefined)[] | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            multiple: true;
        } & {
            parse: import("@oclif/core/lib/interfaces/parser.js").FlagParser<string, string, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            defaultHelp?: import("@oclif/core/lib/interfaces/parser.js").FlagDefaultHelp<string, import("@oclif/core/lib/interfaces/parser.js").CustomOptions> | undefined;
            input: string[];
        } & {
            default?: import("@oclif/core/lib/interfaces/parser.js").FlagDefault<string[] | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            multiple: true;
        } & {
            parse: import("@oclif/core/lib/interfaces/parser.js").FlagParser<string | undefined, string, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            defaultHelp?: import("@oclif/core/lib/interfaces/parser.js").FlagDefaultHelp<string | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            input: string[];
        } & {
            default?: import("@oclif/core/lib/interfaces/parser.js").FlagDefault<(string | undefined)[] | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
            multiple: true;
        });
        format: import("@oclif/core/lib/interfaces/parser.js").OptionFlag<string | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
        version: import("@oclif/core/lib/interfaces/parser.js").OptionFlag<string, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
        typecheck: import("@oclif/core/lib/interfaces/parser.js").BooleanFlag<boolean>;
        domain: import("@oclif/core/lib/interfaces/parser.js").OptionFlag<string | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
        scheme: import("@oclif/core/lib/interfaces/parser.js").OptionFlag<string | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
        port: import("@oclif/core/lib/interfaces/parser.js").OptionFlag<string | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
        url: import("@oclif/core/lib/interfaces/parser.js").OptionFlag<string | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
        timeout: import("@oclif/core/lib/interfaces/parser.js").OptionFlag<string | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
        secret: import("@oclif/core/lib/interfaces/parser.js").OptionFlag<string | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
        endpoint: import("@oclif/core/lib/interfaces/parser.js").OptionFlag<string | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
        environment: import("@oclif/core/lib/interfaces/parser.js").OptionFlag<string | undefined, import("@oclif/core/lib/interfaces/parser.js").CustomOptions>;
    };
    namespace args {
        let dbname: import("@oclif/core/lib/interfaces/parser.js").Arg<string | undefined, Record<string, unknown>>;
        let query: import("@oclif/core/lib/interfaces/parser.js").Arg<string | undefined, Record<string, unknown>>;
    }
}
import FaunaCommand_1 = require("../lib/fauna-command.js");
import FaunaCommand = FaunaCommand_1.default;
