"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const faunadb_1 = require("faunadb");
const fauna_command_1 = tslib_1.__importDefault(require("../lib/fauna-command"));
/**
 * Despite its name, returns the first 1000 databases defined.
 * "1000 databases ought to be enough for anybody".
 */
function allDatabasesQuery() {
    return faunadb_1.query.Map(faunadb_1.query.Paginate(faunadb_1.query.Databases(), { size: 1000 }), faunadb_1.query.Lambda("x", faunadb_1.query.Get(faunadb_1.query.Var("x"))));
}
class ListDatabasesCommand extends fauna_command_1.default {
    async run() {
        return this.withClient((client) => {
            this.log("listing databases");
            return client
                .query(allDatabasesQuery())
                .then((res) => {
                if (res.data.length > 0) {
                    res.data.forEach((el) => {
                        this.log(el.ref.id);
                    });
                }
                else {
                    this.log("No databases created");
                }
            })
                .catch((err) => {
                this.error(err.message);
            });
        }, undefined, // is dbScope, an optional param
        undefined // is role, an optional param
        );
    }
}
ListDatabasesCommand.description =
    "List child databases in the current database.";
ListDatabasesCommand.examples = ["$ fauna list-databases"];
ListDatabasesCommand.flags = {
    ...fauna_command_1.default.flags,
};
module.exports = ListDatabasesCommand;
