"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const schema_command_1 = tslib_1.__importDefault(require("../../lib/schema-command"));
const node_fetch_1 = tslib_1.__importDefault(require("node-fetch"));
class DiffSchemaCommand extends schema_command_1.default {
    async run() {
        const fps = this.gatherRelativeFSLFilePaths();
        const files = this.read(fps);
        try {
            const { url, secret } = await this.fetchsetup();
            const res = await (0, node_fetch_1.default)(new URL("/schema/1/validate?force=true", url), {
                method: "POST",
                headers: { AUTHORIZATION: `Bearer ${secret}` },
                body: this.body(files),
            });
            const json = await res.json();
            if (json.error) {
                this.error(json.error.message);
            }
            this.log(json.diff ? json.diff : "No schema differences");
        }
        catch (err) {
            this.error(err);
        }
    }
}
DiffSchemaCommand.flags = {
    ...schema_command_1.default.flags,
};
DiffSchemaCommand.description = "Print the diff between local and remote schema.";
DiffSchemaCommand.examples = [
    "$ fauna schema diff",
    "$ fauna schema diff --dir schemas/myschema",
];
exports.default = DiffSchemaCommand;
