"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const prompts_1 = require("@inquirer/prompts");
const schema_command_1 = tslib_1.__importDefault(require("../../lib/schema-command"));
const node_fetch_1 = tslib_1.__importDefault(require("node-fetch"));
const core_1 = require("@oclif/core");
class PushSchemaCommand extends schema_command_1.default {
    async run() {
        var _a;
        const fps = this.gatherRelativeFSLFilePaths();
        const files = this.read(fps);
        try {
            const { url, secret } = await this.fetchsetup();
            if ((_a = this.flags) === null || _a === void 0 ? void 0 : _a.force) {
                // Just push.
                const res = await (0, node_fetch_1.default)(new URL("/schema/1/update?force=true", url), {
                    method: "POST",
                    headers: { AUTHORIZATION: `Bearer ${secret}` },
                    body: this.body(files),
                });
                const json = await res.json();
                if (json.error) {
                    this.error(json.error.message);
                }
            }
            else {
                // Confirm diff, then push it.
                const res = await (0, node_fetch_1.default)(new URL("/schema/1/validate?force=true", url), {
                    method: "POST",
                    headers: { AUTHORIZATION: `Bearer ${secret}` },
                    body: this.body(files),
                });
                const json = await res.json();
                if (json.error) {
                    this.error(json.error.message);
                }
                let message = "Accept and push changes?";
                if (json.diff) {
                    this.log(`Proposed diff:\n`);
                    this.log(json.diff);
                }
                else {
                    this.log("No logical changes.");
                    message = "Push file contents anyway?";
                }
                const confirmed = await (0, prompts_1.confirm)({
                    message,
                    default: false,
                });
                if (confirmed) {
                    const res = await (0, node_fetch_1.default)(new URL(`/schema/1/update?version=${json.version}`, url), {
                        method: "POST",
                        headers: { AUTHORIZATION: `Bearer ${secret}` },
                        body: this.body(files),
                    });
                    const json0 = await res.json();
                    if (json0.error) {
                        this.error(json0.error.message);
                    }
                }
                else {
                    this.log("Push cancelled");
                }
            }
        }
        catch (err) {
            this.error(err);
        }
    }
}
PushSchemaCommand.flags = {
    ...schema_command_1.default.flags,
    force: core_1.Flags.boolean({
        description: "Push the change without a diff or schema version check",
        default: false,
    }),
};
PushSchemaCommand.description = "Push the current project's .fsl files to Fauna.";
PushSchemaCommand.examples = [
    "$ fauna schema push",
    "$ fauna schema push --dir schemas/myschema",
];
exports.default = PushSchemaCommand;
