import { Secret } from "../secret";
import { Environment, ProjectConfig } from "./project-config";
import { Endpoint, RootConfig } from "./root-config";
export { Endpoint, Environment, ProjectConfig, RootConfig };
export declare const PROJECT_FILE_NAME = ".fauna-project";
export declare class InvalidConfigError extends Error {
}
export declare class Config {
    keyName: string;
    private config;
    constructor(keyName: string, config: {
        [key: string]: unknown;
    });
    strOpt(key: string): string | undefined;
    keys(): Array<string>;
    numberOpt(key: string): number | undefined;
    object(key: string): Config;
    objectExists(key: string): boolean;
    str(key: string): string;
    number(key: string): number;
    require<T>(key: string, value: T | undefined): T;
    allObjectsWhere(pred: (_: string) => boolean): [string, Config][];
    objectsIn(key: string): [string, Config][];
}
export type ShellOpts = {
    flags?: {
        [key: string]: any;
    };
    rootConfig?: {
        [key: string]: any;
    };
    projectPath?: string;
    projectConfig?: {
        [key: string]: any;
    };
};
export type EndpointConfig = {
    secret: Secret;
    url: string;
    name?: string;
    graphqlHost: string;
    graphqlPort: number;
};
export interface LogChannel {
    warn(_: string): void;
    log(_: string): void;
}
export declare class ShellConfig {
    flags: Config;
    rootConfig: RootConfig;
    projectConfig: ProjectConfig | undefined;
    secretFlag?: Secret;
    environment: Environment | undefined;
    endpoint: Endpoint | undefined;
    projectPath: string | undefined;
    errors: string[];
    static read(flags: any, log?: LogChannel): ShellConfig;
    static readWithOverrides(opts?: ShellOpts): ShellConfig;
    constructor(opts: ShellOpts);
    validate: () => void;
    lookupEndpoint: (opts: {
        scope?: string;
    }) => EndpointConfig;
    configErrors(): string[];
    /**
     * Saves the project config, if present.
     */
    saveProjectConfig(): void;
    /**
     * Saves the root config.
     */
    saveRootConfig(): void;
    projectConfigFile(): string | undefined;
}
export declare const getRootConfigPath: () => string;
export declare const getProjectConfigPath: (start?: string) => string | undefined;
export declare const fileExists: (filePath: string) => boolean;
