"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Environment = exports.ProjectConfig = void 0;
const tslib_1 = require("tslib");
const ini = require("ini");
const fs = tslib_1.__importStar(require("fs"));
const _1 = require(".");
// Represents `.fauna-project`
class ProjectConfig {
    /**
     * This method is used to obtain an empty project config when fauna project init is used.
     */
    static initialConfig(fslDir) {
        return new ProjectConfig({}, undefined, fslDir);
    }
    constructor(environments, defaultEnvironment, schemaDir) {
        this.environments = environments;
        this.defaultEnvironment = defaultEnvironment;
        this.schemaDir = schemaDir;
    }
    static fromConfig(config) {
        const defaultEnvironment = config.strOpt(ProjectConfig.DEFAULT_FIELD_NAME);
        const fslDir = config.strOpt(ProjectConfig.SCHEMA_DIRECTORY_FIELD_NAME);
        const environments = config.objectExists(ProjectConfig.ENVIRONMENT_FIELD_NAME)
            ? Object.fromEntries(config.objectsIn("environment").map(([k, v]) => [k, new Environment(v)]))
            : {};
        if (defaultEnvironment && environments[defaultEnvironment] === undefined) {
            throw new _1.InvalidConfigError(`Default environment '${defaultEnvironment}' was not found`);
        }
        return new ProjectConfig(environments, defaultEnvironment, fslDir);
    }
    validate(rootConfig) {
        for (const environment of Object.values(this.environments)) {
            if (rootConfig.endpoints[environment.endpoint] === undefined) {
                throw new _1.InvalidConfigError(`Endpoint '${environment.endpoint}' not found in ~/.fauna-shell`);
            }
        }
    }
    save(path) {
        const config = {
            ...(this.schemaDir
                ? { [ProjectConfig.SCHEMA_DIRECTORY_FIELD_NAME]: this.schemaDir }
                : {}),
            ...(this.defaultEnvironment
                ? { [ProjectConfig.DEFAULT_FIELD_NAME]: this.defaultEnvironment }
                : {}),
            [ProjectConfig.ENVIRONMENT_FIELD_NAME]: this.environments,
        };
        const encoded = ini.encode(config);
        fs.writeFileSync(path, encoded);
    }
}
exports.ProjectConfig = ProjectConfig;
ProjectConfig.DEFAULT_FIELD_NAME = "default";
ProjectConfig.SCHEMA_DIRECTORY_FIELD_NAME = "schema_directory";
ProjectConfig.ENVIRONMENT_FIELD_NAME = "environment";
class Environment {
    constructor(config) {
        this.endpoint = config.str("endpoint");
        this.database = config.str("database");
    }
}
exports.Environment = Environment;
