import { Config, EndpointConfig } from ".";
import { Secret } from "../secret";
export declare class RootConfig {
    defaultEndpoint?: string;
    endpoints: {
        [key: string]: Endpoint;
    };
    invalidEndpoints: string[];
    constructor(config: Config);
    isEmpty(): boolean;
    /**
     * If there is an endpoint object in the config, and it has a
     * object underneath it, we are saying that it uses the
     *
     * [endpoint.myacct]
     * secret=***
     *
     * structure. This allows us to support a legacy config that has
     * a top level endpoint named endpoint.  Once we rewrite the config
     * to be endpoint object based adding one manually like that
     * will not be recognized.
     */
    private static configContainsNestedEndpointStructure;
    save(path: string): void;
    toIni(): {
        endpoint: {
            [k: string]: {
                graphqlPort?: number | undefined;
                graphqlHost?: string | undefined;
                url?: string | undefined;
                secret: string;
            };
        };
        default?: string | undefined;
    };
}
/**
 * Represents an endpoint, or a section of `~/.fauna-shell`.
 *
 * An endpoint contains:
 * - A secret. This is the accout secret for this database.
 * - An optional URL. This is the URL of the database. It defaults to `https://db.fauna.com`.
 * - An optional GraphQL host. This is the host to use for GraphQL requests. It defaults to `graphql.fauna.com`.
 * - An optional GraphQL port. This is the port to use for GraphQL requests. It defaults to `443`.
 */
export declare class Endpoint {
    name?: string;
    secret: Secret;
    url: string;
    graphqlHost: string;
    graphqlPort: number;
    static fromConfig(name: string, config: Config): Endpoint | undefined;
    constructor(opts: {
        name?: string;
        secret: Secret;
        url?: string;
        graphqlHost?: string;
        graphqlPort?: number;
    });
    makeScopedEndpoint(databaseScope?: string[]): EndpointConfig;
    /**
     * Gets a database URL from config.
     */
    static getURLFromConfig: (config: Config) => string | undefined;
    /**
     * Gets a database URL from command line flags.
     *
     * Note: this is the same as `getURLFromConfig`. Its left different so that
     * we can change flags later, without breaking config parsing.
     */
    static getURLFromFlags: (flags: Config) => string | undefined;
    static getURL: (opts: {
        url?: string;
        scheme?: string;
        domain?: string;
        port?: number;
    }) => string | undefined;
    toIni(): {
        graphqlPort?: number | undefined;
        graphqlHost?: string | undefined;
        url?: string | undefined;
        secret: string;
    };
}
