export type QueryResponse<T> = QuerySuccess<T> | QueryFailure;
export type QueryInfo = {
    headers: any;
    body: {
        summary: string;
    };
};
export type QuerySuccess<T> = QueryInfo & {
    status: 200;
    body: {
        data: T;
    };
};
export type QueryFailure = QueryInfo & {
    status: 400;
    body: {
        error: {
            code: string;
            message?: string;
        };
    };
};
export default class FaunaClient {
    session: any;
    secret: string;
    timeout?: number;
    constructor(opts: {
        endpoint: string;
        secret: string;
        timeout?: number;
    });
    query<T>(query: string, opts?: {
        format?: string;
        typecheck?: boolean;
        secret?: string;
    }): Promise<QueryResponse<T>>;
    close(): Promise<void>;
}
