"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const http2_1 = require("http2");
class FaunaClient {
    constructor(opts) {
        this.session = (0, http2_1.connect)(opts.endpoint, {
            peerMaxConcurrentStreams: 50,
        })
            .once("error", () => this.close())
            .once("goaway", () => this.close());
        this.secret = opts.secret;
        this.timeout = opts.timeout;
    }
    async query(query, opts) {
        var _a, _b, _c;
        const { format, typecheck, secret } = {
            format: (_a = opts === null || opts === void 0 ? void 0 : opts.format) !== null && _a !== void 0 ? _a : "simple",
            typecheck: (_b = opts === null || opts === void 0 ? void 0 : opts.typecheck) !== null && _b !== void 0 ? _b : undefined,
            secret: (_c = opts === null || opts === void 0 ? void 0 : opts.secret) !== null && _c !== void 0 ? _c : this.secret,
        };
        return new Promise((resolvePromise, rejectPromise) => {
            var _a, _b, _c;
            let req;
            const onResponse = (http2ResponseHeaders) => {
                const status = http2ResponseHeaders[http2_1.constants.HTTP2_HEADER_STATUS];
                let responseData = "";
                req.on("data", (chunk) => {
                    responseData += chunk;
                });
                req.on("end", () => {
                    resolvePromise({
                        status,
                        body: JSON.parse(responseData),
                        headers: http2ResponseHeaders,
                    });
                });
            };
            try {
                const httpRequestHeaders = {
                    Authorization: `Bearer ${secret}`,
                    "x-format": format,
                    "X-Fauna-Source": "Fauna Shell",
                    [http2_1.constants.HTTP2_HEADER_PATH]: "/query/1",
                    [http2_1.constants.HTTP2_HEADER_METHOD]: "POST",
                    ...((_a = (typecheck && { "x-typecheck": typecheck })) !== null && _a !== void 0 ? _a : {}),
                    ...((_b = (this.timeout && { "x-query-timeout-ms": this.timeout })) !== null && _b !== void 0 ? _b : {}),
                };
                req = this.session
                    .request(httpRequestHeaders)
                    .setEncoding("utf8")
                    .on("error", (error) => rejectPromise(error))
                    .on("response", onResponse);
                req.write(JSON.stringify({ query }), "utf8");
                // req.setTimeout must be called before req.end()
                req.setTimeout(((_c = this.timeout) !== null && _c !== void 0 ? _c : 0) + 5000, () => {
                    req.destroy(new Error(`Client timeout`));
                });
                req.end();
            }
            catch (error) {
                rejectPromise(error);
            }
        });
    }
    async close() {
        this.session.close();
    }
}
exports.default = FaunaClient;
