export default getFaunaImportWriter;
/**
 * Creates a function that consumes a stream of objects and writes creates each object
 * as a document in the given collection.
 * @param {Array<string>} typeTranslations - any custom type translations to perform on fields.
 * @param {faunadb.Client} client - a {faunadb.Client} configured for the account to store the data in.
 * @param {string} collection - the name of the {fauna.query.Collection} to write data to.
 * @param {string} inputFile - the path to the input file.
 * @param {object} options - object containing optional arguments.
 * @param {boolean} options.isDryRun - if true dry run the import - committing no documents. to Fauna. Otherwise, write documents to Fauna. Defaults to false.
 * @param {(string) => any} options.logger - the logger to be used to issue warnings
 * @param {(string) => any} options.infoLogger - the logger to be used to issue informational messages
 * @param {number} options.writeOpsPerSecondLimit - the rate at which data can be written to Fauna, defaults to 100 write ops per second.
 * @param {number} options.requestsPerSecondLimit - the rate at which data can be written to Fauna, defaults to 10 requests per second.
 * @param {number} options.maxParallelRequests - the maximum number of parallel requests to issue to Fauna, defaults to 10.
 * @return {(inputStream: ReadableStream) => void} a function that asynchronously writes
 * all the data in the inputSteam to Fauna. All data will be written to the collection specified
 * in input, and will use the provided client. This function is capable of consuming a stream
 * in a [stream pipeline](https://nodejs.org/api/stream.html).
 */
declare function getFaunaImportWriter(typeTranslations: Array<string>, client: faunadb.Client, collection: string, inputFile: string, failedRowsObj: any, { isDryRun, logger, infoLogger, writeOpsPerSecondLimit, requestsPerSecondLimit, maxParallelRequests, indexEstimation, }: {
    isDryRun?: boolean | undefined;
    logger?: {
        (...data: any[]): void;
        (message?: any, ...optionalParams: any[]): void;
    } | undefined;
    infoLogger?: {
        (...data: any[]): void;
        (message?: any, ...optionalParams: any[]): void;
    } | undefined;
    writeOpsPerSecondLimit?: number | undefined;
    requestsPerSecondLimit?: number | undefined;
    maxParallelRequests?: number | undefined;
    indexEstimation?: number | undefined;
}): (inputStream: ReadableStream) => void;
