/**
 * An error translating an object with a {FaunaObjectTranslater}.
 */
export class TranslationError extends Error {
}
/**
 * Helper class for cleaning objects prior to persistence in Fauna.
 * It has two main objectives:
 *   - trim input strings to remove unneeded whitespace
 *   - cast types as specified by input
 **/
export class FaunaObjectTranslator {
    static "__#1@#NUMBER_REGEX": RegExp;
    static "__#1@#TRULY": (string | number | boolean)[];
    static "__#1@#getErrorValue"(val: any): string;
    /**
     * Constructs a new FaunaObjectTranslator
     * @param {Array<string>} typeTranslations - custom typeTranslations to perform on object
     *   keys. Must be provided as an array of strings in the form:
     *      [keyName::typeTranslationFunction, ...]
     *   Supported typeTranslationFunctions are: number, dateString, dateEpochMills, dateEpochSeconds, bool
     *   e.g. [myKey::bool, myOtherKey::number, myFinalKey::date_string]
     */
    constructor(typeTranslations: Array<string>, logger?: {
        (...data: any[]): void;
        (message?: any, ...optionalParams: any[]): void;
    });
    /**
     * Translates the rawData to a cleaned Fauna object - applying
     * any type transformations and trimming field names.
     * @param {object} rawData - the uncleaned record
     * @return {object} An object holding the cleaned data.
     * @throws {Error} if translation fails
     */
    getRecord(rawData: object): object;
    #private;
}
