"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Secret = void 0;
class Secret {
    constructor(opts) {
        var _a;
        this.key = opts.key;
        this.allowDatabase = opts.allowDatabase;
        this.databaseScope = (_a = opts.databaseScope) !== null && _a !== void 0 ? _a : [];
    }
    static parseFlag(key) {
        if (key.length === 0) {
            throw new Error("Secret cannot be empty");
        }
        return new Secret({ key, allowDatabase: !key.includes(":") });
    }
    static parse(key) {
        if (key.length === 0) {
            throw new Error("Secret cannot be empty");
        }
        if (key.includes(":")) {
            throw new Error("Secret cannot be scoped");
        }
        return new Secret({ key, allowDatabase: true });
    }
    buildSecret(opts) {
        var _a;
        let secret = this.key;
        if (this.databaseScope.length > 0) {
            secret += `:${this.databaseScope.join("/")}`;
        }
        if ((opts === null || opts === void 0 ? void 0 : opts.role) !== undefined || this.databaseScope.length > 0) {
            const role = (_a = opts === null || opts === void 0 ? void 0 : opts.role) !== null && _a !== void 0 ? _a : "admin";
            secret += ["admin", "client", "server", "server-readonly"].includes(role)
                ? `:${role}`
                : `:@role/${role}`;
        }
        return secret;
    }
    /**
     * Parses the given scope, appends it to the `Secret`, and returns the new
     * secret. This mutates `this`.
     */
    appendScope(scope) {
        if (this.allowDatabase) {
            this.databaseScope.push(...scope.split("/"));
            return this;
        }
        else {
            throw new Error("Cannot specify database with a secret that contains a database");
        }
    }
    clone() {
        return new Secret({
            key: this.key,
            allowDatabase: this.allowDatabase,
            databaseScope: [...this.databaseScope],
        });
    }
}
exports.Secret = Secret;
